tiled.structures.array.Endianness
=================================

.. currentmodule:: tiled.structures.array

.. autoclass:: Endianness

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Endianness.big
      ~Endianness.little
      ~Endianness.not_applicable
   
   